@@ -1040,7 +1040,7 @@ window_cmd_help_about (GtkAction *action,
 			       "program-name", _("GNOME Web Browser"),
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002–2004 Marco Pesenti Gritti\n"
-			                    "Copyright © 2003–2010 The GNOME Web Browser Developers",
+			                    "Copyright © 2003–2011 The GNOME Web Browser Developers",
 			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
@@ -1073,18 +1073,12 @@ window_cmd_tabs_next (GtkAction *action,
 		      EphyWindow *window)
 {
 	GtkNotebook *nb;
-	gint page;
+	gboolean handled;
 
 	nb = GTK_NOTEBOOK (ephy_window_get_notebook (window));
 	g_return_if_fail (nb != NULL);
 
-	page = gtk_notebook_get_current_page (nb);
-	g_return_if_fail (page != -1);
-
-	if (page < gtk_notebook_get_n_pages (nb) - 1)
-	{
-		gtk_notebook_set_current_page (nb, page + 1);
-	}
+	g_signal_emit_by_name (nb, "change-current-page", 1, &handled);
 }
 
 void
@@ -1092,18 +1086,12 @@ window_cmd_tabs_previous (GtkAction *action,
 			  EphyWindow *window)
 {
 	GtkNotebook *nb;
-	gint page;
+	gboolean handled;
 
 	nb = GTK_NOTEBOOK (ephy_window_get_notebook (window));
 	g_return_if_fail (nb != NULL);
 
-	page = gtk_notebook_get_current_page (nb);
-	g_return_if_fail (page != -1);
-
-	if (page > 0)
-	{
-		gtk_notebook_set_current_page (nb, page - 1);
-	}
+	g_signal_emit_by_name (nb, "change-current-page", -1, &handled);
 }
 
 void
